@@ -22,11 +22,11 @@
  */
 
 #include <getopt.h>
-#include <QSettings>
 #include "options.h"
 #include "config.h"
 #include "../HdrCreation/createhdr.h"
 #include "commandline.h"
+#include "global.h"
 #include "../Threads/loadHdrThread.h"
 #include "../Threads/tonemapperThread.h"
 #include "../Exif/exif_operations.h"
@@ -36,13 +36,19 @@
 void writeRGBEfile (pfs::Frame* inputpfsframe, const char* outfilename);
 void writeEXRfile  (pfs::Frame* inputpfsframe, const char* outfilename);
 
-#ifdef WIN32
+#if defined(__FreeBSD__) || defined(WIN32)
 #define error(Z) { fprintf(stderr,Z); exit(1); }
 #else
 #include <error.h>
 #define error(Z) error(1,0,Z);
 #endif
 
+///string is a QString with a %1 in it
+#define VERBOSEPRINT( string, argument ) \
+if (verbose) { \
+	fprintf(stdout, qPrintable(tr( string "\n" ).arg( argument )) ); \
+}
+
 
 static struct option cmdLineOptions[] = {
 	{ "verbose", no_argument, NULL, 'v' },
@@ -63,8 +69,7 @@ static struct option cmdLineOptions[] = {
 CommandLineInterfaceManager::CommandLineInterfaceManager(const int argc, char **argv) : argc(argc), argv(argv) {
 	hdrCreationManager=NULL;
 	align_mode=NO_ALIGN;
-	qtpfsgui_options=new qtpfsgui_opts();
-	QtPfsGuiOptions::loadOptions(qtpfsgui_options);
+	qtpfsgui_options=QtpfsguiOptions::getInstance();
 	connect(this,SIGNAL(startParsing()),this,SLOT(parseArgs()),Qt::QueuedConnection);
 	emit startParsing();
 }
@@ -288,28 +293,31 @@ void CommandLineInterfaceManager::parseArgs() {
 	}
 	for (int index = optind; index < argc; index++) {
 		inputFiles << QString(argv[index]);
-		qDebug("Input file %s", argv[index]);
+		VERBOSEPRINT("Input file %1" , argv[index]);
 	}
 
 	if (!ev.isEmpty() && ev.count()!=inputFiles.count())
 		error(qPrintable(tr("Error: The number of EV values specified is different from the number of input files.")));
 
 	//now validate operation mode.
-	if (inputFiles.size()!=0 && loadHdrFilename.isEmpty())
+	if (inputFiles.size()!=0 && loadHdrFilename.isEmpty()) {
 		operation_mode=CREATE_HDR_MODE;
-	else if (!loadHdrFilename.isEmpty() && inputFiles.size()==0 )
+		VERBOSEPRINT("Running in HDR-creation mode. %1" , "");
+	} else if (!loadHdrFilename.isEmpty() && inputFiles.size()==0 ) {
 		operation_mode=LOAD_HDR_MODE;
-	else {
+		VERBOSEPRINT("Running in Load-HDR mode. %1" , "");
+	} else {
 		printHelp(argv[0]);
 		error("Wrong combination of parameters.");
 	}
 
 	if (operation_mode==CREATE_HDR_MODE) {
-		QSettings settings("Qtpfsgui", "Qtpfsgui");
-		QString temppath = settings.value(KEY_TEMP_RESULT_PATH, QDir::currentPath()).toString();
-		int numthreads=settings.value(KEY_NUM_BATCH_THREADS,1).toInt();
-		QStringList rawopts=settings.value(KEY_EXTERNAL_DCRAW_OPTIONS,"-T").toStringList();
-		hdrCreationManager = new HdrCreationManager(numthreads, temppath, rawopts);
+		if (verbose) {
+			VERBOSEPRINT("Temporary directory: %1",qtpfsgui_options->tempfilespath);
+			VERBOSEPRINT("Dcraw parameters: %1",qtpfsgui_options->dcraw_options.join(" ") );
+			VERBOSEPRINT("Using %1 threads.", qtpfsgui_options->num_threads);
+		}
+		hdrCreationManager = new HdrCreationManager(qtpfsgui_options->num_threads, qtpfsgui_options->tempfilespath, qtpfsgui_options->dcraw_options);
 		connect(hdrCreationManager,SIGNAL(finishedLoadingInputFiles(QStringList)),this, SLOT(finishedLoadingInputFiles(QStringList)));
 		connect(hdrCreationManager,SIGNAL(errorWhileLoading(QString)),this, SLOT(errorWhileLoading(QString)));
 		connect(hdrCreationManager, SIGNAL(finishedAligning()), this, SLOT(createHDR()));
@@ -318,25 +326,28 @@ void CommandLineInterfaceManager::parseArgs() {
 		hdrCreationManager->loadInputFiles();
 	}
 	else {
-		LoadHdrThread *loadthread = new LoadHdrThread(loadHdrFilename, "", qtpfsgui_options);
+		LoadHdrThread *loadthread = new LoadHdrThread(loadHdrFilename, "");
 		connect(loadthread, SIGNAL(finished()), loadthread, SLOT(deleteLater()));
 		connect(loadthread, SIGNAL(hdr_ready(pfs::Frame*,QString)), this, SLOT(loadFinished(pfs::Frame*,QString)));
 		connect(loadthread, SIGNAL(load_failed(QString)), this, SLOT(errorWhileLoading(QString)));
 		loadthread->start();
+		VERBOSEPRINT("Loading file %1.",loadHdrFilename);
 	}
 }
 
-void CommandLineInterfaceManager::loadFinished(pfs::Frame* hdr, QString /*fname*/) {
+void CommandLineInterfaceManager::loadFinished(pfs::Frame* hdr, QString fname) {
+	VERBOSEPRINT("Successfully loaded file %1.",fname);
 	HDR=hdr;
 	saveHDR();
 }
 
 void CommandLineInterfaceManager::finishedLoadingInputFiles(QStringList filesLackingExif) {
 	if (filesLackingExif.size()!=0) {
-		if (!ev.isEmpty())
+		if (!ev.isEmpty()) {
 			for(int i=0; i<ev.size(); i++)
 				hdrCreationManager->setEV(ev.at(i),i);
-		else
+			VERBOSEPRINT("EV values have been assigned. %1","");
+		} else
 			error(qPrintable(tr("Error: Exif data missing in images and EV values not specifed on the commandline, bailing out.")));
 	}
 	hdrCreationManager->checkEVvalues();
@@ -353,17 +364,19 @@ void CommandLineInterfaceManager::errorWhileLoading(QString errormessage) {
 	exit(1);
 }
 void CommandLineInterfaceManager::ais_failed(QProcess::ProcessError) {
-	errorWhileLoading("Failed executing align_image_stack");
+	errorWhileLoading(tr("Failed executing align_image_stack"));
 }
 
 void CommandLineInterfaceManager::createHDR() {
 	hdrCreationManager->removeTempFiles();
+	VERBOSEPRINT("Creating (in memory) the HDR. %1","");
 	HDR=hdrCreationManager->createHdr(false,1);
 	saveHDR();
 }
 
 void CommandLineInterfaceManager::saveHDR() {
 	if (!saveHdrFilename.isEmpty()) {
+		VERBOSEPRINT("Saving to file %1.",saveHdrFilename);
 		QFileInfo qfi(saveHdrFilename);
 		if (qfi.suffix().toUpper()=="EXR") {
 			writeEXRfile(HDR,qfi.filePath().toUtf8().constData());
@@ -381,8 +394,10 @@ void CommandLineInterfaceManager::saveHDR() {
 			pfsio.writeFrame(HDR,qfi.filePath());
 			HDR->convertXYZChannelsToRGB();
 		} else {
-			error("Error, please specify a supported HDR file formats.");
+			error("Error, please specify a supported HDR file format.");
 		}
+	} else {
+		VERBOSEPRINT("NOT Saving HDR image to file. %1","");
 	}
 
 	startTonemap();
@@ -390,22 +405,32 @@ void CommandLineInterfaceManager::saveHDR() {
 
 void  CommandLineInterfaceManager::startTonemap() {
 	if (!saveLdrFilename.isEmpty()) {
+		VERBOSEPRINT("Tonemapping requested, saving to file %1.",saveLdrFilename);
 		//now check if user wants to resize (create thread with either -2 or true original size as first argument in ctor, see options.cpp).
 		int origxsize= (tmopts->xsize==-2) ? -2 : HDR->getWidth();
 		TonemapperThread *thread = new TonemapperThread(origxsize, *tmopts);
 		connect(thread, SIGNAL(ImageComputed(const QImage&,tonemapping_options*)), this, SLOT(tonemapTerminated(const QImage&,tonemapping_options*)));
+		pfs::DOMIO pfsio;
+		pfsio.writeFrame(HDR, qtpfsgui_options->tempfilespath+"/original.pfs");
+		pfsio.freeFrame(HDR);
+		thread->start();
 	} else {
+		VERBOSEPRINT("Tonemapping NOT requested. %1","");
 		emit finishedParsing();
 	}
 }
 
 void CommandLineInterfaceManager::tonemapTerminated(const QImage& newimage,tonemapping_options*) {
+	QFile::remove(qtpfsgui_options->tempfilespath+"/original.pfs");
+	QFile::remove(qtpfsgui_options->tempfilespath+"/after_resize.pfs");
+	QFile::remove(qtpfsgui_options->tempfilespath+"/after_pregamma.pfs");
 	QFileInfo qfi(saveLdrFilename);
 	if (!newimage.save(saveLdrFilename, qfi.suffix().toAscii().constData(), 100)) {
 		error(qPrintable(tr("ERROR: Cannot save to file: %1").arg(saveLdrFilename)));
 	} else {
 		TMOptionsOperations operations(tmopts);
-		ExifOperations::writeExifData(saveLdrFilename.toStdString(),operations.getExifComment().toStdString());
+		//ExifOperations methods want a std::string, we need to use the QFile::encodeName(QString).constData() trick to cope with utf8 characters.
+		ExifOperations::writeExifData(QFile::encodeName(saveLdrFilename).constData(),operations.getExifComment().toStdString());
 	}
 	emit finishedParsing();
 }
@@ -439,15 +464,15 @@ void CommandLineInterfaceManager::printHelp(char * progname) {
 	-e --ev EV1,EV2,...    Specify numerical EV values (as many as INPUTFILES).\n \
 	-c --config            HDR creation config. Possible values: \n\
 		weight=triangular|gaussian|plateau:response_curve=from_file|linear|gamma|log|robertson:model=robertson|debevec:curve_filename=your_file_here.m \n\
-		(Default is triangular,linear,debevec) \n\
+		(Default is weight=triangular:response_curve=linear:model=debevec) \n\
 	-l --load HDR_FILE     Load an HDR instead of creating a new one. \n \
-	-s --save HDR_FILE     Save to a HDR file format. \n \
-	-g --gamma VALUE       Gamma value to use during tone mapping. \n \
-	-r --resize VALUE      Width want to resize your HDR to (resized before gamma and tone mapping) \n \
-	-t --tmo               Tone mapping operator. Possible values: \n\
+	-s --save HDR_FILE     Save to a HDR file format. (default: don't save) \n \
+	-g --gamma VALUE       Gamma value to use during tone mapping. (default: 1) \n \
+	-r --resize VALUE      Width you want to resize your HDR to (resized before gamma and tone mapping) \n \
+	-t --tmo               Tone mapping operator. Legal values are: \n\
 		ashikhmin|drago|durand|fattal|pattanaik|reinhard02|reinhard05|mantiuk\n \
 		(Default is mantiuk)\n \
-	-p --tmoptions         Tone mapping operator options. Possible values: \n\
+	-p --tmoptions         Tone mapping operator options. Legal values are: \n\
 		alpha=VALUE:beta=VALUE:color=VALUE:noise=VALUE:new=true|false (for fattal)\n\
 		contrast=VALUE:saturation=VALUE:equalization=true|false (for mantiuk)\n\
 		localcontrast=VALUE:eq=2|4:simple=true|false (for ashikhmin)\n\
@@ -456,9 +481,10 @@ void CommandLineInterfaceManager::printHelp(char * progname) {
 		local=true|false:autolum=true|false:cone=VALUE:rod=VALUE:multiplier=VALUE (for pattanaik)\n\
 		scales=true|false:key=VALUE:phi=VALUE:num=VALUE:low=VALUE:high=VALUE (for reinhard02)\n\
 		brightness=VALUE:chroma=VALUE:lightness=VALUE (for reinhard05)\n\
-		(Default is contrast=0.3:equalization=false:saturation=1.8)\n \
+		(default is contrast=0.3:equalization=false:saturation=1.8, see also -o)\n \
 	-o --output LDR_FILE   File name you want to save your tone mapped LDR to.\n \
+	                       (No tonemapping is performed unless -o is specified).\n \
 	\n\
-You must either load an existing HDR file (via the -l option) or specify INPUTFILES to create a new one.\n").arg(progname).arg(progname);
+You must either load an existing HDR file (via the -l option) or specify INPUTFILES to create a new HDR.\n").arg(progname).arg(progname);
 	fprintf(stderr,qPrintable(help));
 }
