@@ -28,17 +28,13 @@
 #include <QProcess>
 #include <QTextStream>
 
-#if defined(__FreeBSD__) && __FreeBSD__ < 6
-extern "C" {
-#include "../arch/freebsd/s_exp2f.c"
-}
-#endif
+#include "../arch/freebsd/math.h"
 
 #include "newHdrWizard.h"
 #include "editingTools.h"
 #include "../Common/config.h"
 
-HdrWizardForm::HdrWizardForm(QWidget *p, qtpfsgui_opts *options) : QDialog(p), opts(options), settings("Qtpfsgui", "Qtpfsgui"), hdrCreationManager(NULL), loadcurvefilename(""), savecurvefilename("") {
+HdrWizardForm::HdrWizardForm(QWidget *p) : QDialog(p), hdrCreationManager(NULL), loadcurvefilename(""), savecurvefilename("") {
 	setupUi(this);
 
 	weights_in_gui[0]=TRIANGULAR;
@@ -58,7 +54,7 @@ HdrWizardForm::HdrWizardForm(QWidget *p, qtpfsgui_opts *options) : QDialog(p), o
 	connect(tableWidget, SIGNAL(currentCellChanged(int,int,int,int)), this, SLOT(inputHdrFileSelected(int)));
 
 	connect(NextFinishButton,SIGNAL(clicked()),this,SLOT(NextFinishButtonClicked()));
-	connect(cancelButton,SIGNAL(clicked()),this,SLOT(cancelButtonClicked()));
+	connect(cancelButton,SIGNAL(clicked()),this,SLOT(reject()));
 	connect(pagestack,SIGNAL(currentChanged(int)),this,SLOT(currentPageChangedInto(int)));
 
 	connect(predefConfigsComboBox,SIGNAL(activated(int)),this,
@@ -87,6 +83,7 @@ HdrWizardForm::HdrWizardForm(QWidget *p, qtpfsgui_opts *options) : QDialog(p), o
 	SLOT(loadRespCurveFilename(const QString&)));
 	connect(loadImagesButton,SIGNAL(clicked()),this,SLOT(loadImagesButtonClicked()));
 
+	QtpfsguiOptions *opts=QtpfsguiOptions::getInstance();
 	hdrCreationManager = new HdrCreationManager ( opts->num_threads, opts->tempfilespath, opts->dcraw_options );
 	connect(hdrCreationManager, SIGNAL(fileLoaded(int,QString,float)), this, SLOT(fileLoaded(int,QString,float)));
 	connect(hdrCreationManager,SIGNAL(finishedLoadingInputFiles(QStringList)),this, SLOT(finishedLoadingInputFiles(QStringList)));
@@ -95,14 +92,16 @@ HdrWizardForm::HdrWizardForm(QWidget *p, qtpfsgui_opts *options) : QDialog(p), o
 	connect(hdrCreationManager, SIGNAL(finishedAligning()), this, SLOT(finishedAligning()));
 	connect(hdrCreationManager, SIGNAL(ais_failed(QProcess::ProcessError)), this, SLOT(ais_failed(QProcess::ProcessError)));
 
+	connect(this,SIGNAL(rejected()),hdrCreationManager,SLOT(removeTempFiles()));
+
 }
 
 void HdrWizardForm::loadImagesButtonClicked() {
     QString filetypes;
-    filetypes += tr("All formats (*.jpeg *.jpg *.tiff *.tif *.crw *.cr2 *.nef *.dng *.mrw *.orf *.kdc *.dcr *.arw *.raf *.ptx *.pef *.x3f *.raw);;");
+    filetypes += tr("All formats (*.jpeg *.jpg *.tiff *.tif *.crw *.cr2 *.nef *.dng *.mrw *.orf *.kdc *.dcr *.arw *.raf *.ptx *.pef *.x3f *.raw *.sr2);;");
     filetypes += tr("JPEG (*.jpeg *.jpg);;");
     filetypes += tr("TIFF Images (*.tiff *.tif);;");
-    filetypes += tr("RAW Images (*.crw *.cr2 *.nef *.dng *.mrw *.orf *.kdc *.dcr *.arw *.raf *.ptx *.pef *.x3f *.raw)");
+    filetypes += tr("RAW Images (*.crw *.cr2 *.nef *.dng *.mrw *.orf *.kdc *.dcr *.arw *.raf *.ptx *.pef *.x3f *.raw *.sr2)");
 
     QString RecentDirInputLDRs = settings.value(KEY_RECENT_PATH_LOAD_LDRs_FOR_HDR, QDir::currentPath()).toString();
 
@@ -518,8 +517,3 @@ void HdrWizardForm::keyPressEvent(QKeyEvent *event) {
 		emit reject();
 	}
 }
-
-void HdrWizardForm::cancelButtonClicked() {
-	hdrCreationManager->removeTempFiles();
-	reject();
-}
