@@ -38,12 +38,13 @@
 #include "../Threads/loadHdrThread.h"
 #include "../Common/config.h"
 #include "hdrviewer.h"
+#include "../Common/global.h"
 
 pfs::Frame* rotateFrame( pfs::Frame* inputpfsframe, bool clock_wise );
 void writeRGBEfile (pfs::Frame* inputpfsframe, const char* outfilename);
 void writeEXRfile  (pfs::Frame* inputpfsframe, const char* outfilename);
 
-MainGui::MainGui(QWidget *p) : QMainWindow(p), currenthdr(NULL), settings("Qtpfsgui", "Qtpfsgui") {
+MainGui::MainGui(QWidget *p) : QMainWindow(p), currenthdr(NULL) {
 	setupUi(this);
 	//main toolbar setup
 	QActionGroup *toolBarOptsGroup = new QActionGroup(this);
@@ -57,8 +58,8 @@ MainGui::MainGui(QWidget *p) : QMainWindow(p), currenthdr(NULL), settings("Qtpfs
 	workspace->setScrollBarsEnabled( TRUE );
 	setCentralWidget(workspace);
 
-	qtpfsgui_options=new qtpfsgui_opts();
-	load_options(qtpfsgui_options);
+	qtpfsgui_options=QtpfsguiOptions::getInstance();
+	load_options();
 
 	setWindowTitle("Qtpfsgui "QTPFSGUIVERSION);
 
@@ -70,6 +71,7 @@ MainGui::MainGui(QWidget *p) : QMainWindow(p), currenthdr(NULL), settings("Qtpfs
 	connect(rotateccw, SIGNAL(triggered()), this, SLOT(rotateccw_requested()));
 	connect(rotatecw, SIGNAL(triggered()), this, SLOT(rotatecw_requested()));
 	connect(actionResizeHDR, SIGNAL(triggered()), this, SLOT(resize_requested()));
+	connect(action_Projective_Transformation, SIGNAL(triggered()), this, SLOT(projectiveTransf_requested()));
 	connect(actionBatch_Tone_Mapping, SIGNAL(triggered()), this, SLOT(batch_requested()));
 	connect(Low_dynamic_range,SIGNAL(triggered()),this,SLOT(current_mdi_ldr_exp()));
 	connect(Fit_to_dynamic_range,SIGNAL(triggered()),this,SLOT(current_mdi_fit_exp()));
@@ -85,12 +87,13 @@ MainGui::MainGui(QWidget *p) : QMainWindow(p), currenthdr(NULL), settings("Qtpfs
 	connect(actionWhat_s_This,SIGNAL(triggered()),this,SLOT(enterWhatsThis()));
 	connect(actionAbout_Qt,SIGNAL(triggered()),qApp,SLOT(aboutQt()));
 	connect(actionAbout_Qtpfsgui,SIGNAL(triggered()),this,SLOT(aboutQtpfsgui()));
-	connect(OptionsAction,SIGNAL(triggered()),this,SLOT(options_called()));
+	connect(OptionsAction,SIGNAL(triggered()),this,SLOT(preferences_called()));
 	connect(Transplant_Exif_Data_action,SIGNAL(triggered()),this,SLOT(transplant_called()));
 	connect(actionTile,SIGNAL(triggered()),workspace,SLOT(tile()));
 	connect(actionCascade,SIGNAL(triggered()),workspace,SLOT(cascade()));
 	connect(fileExitAction, SIGNAL(triggered()), this, SLOT(fileExit()));
 	connect(menuWindows, SIGNAL(aboutToShow()), this, SLOT(updateWindowMenu()));
+	connect(actionSave_Hdr_Preview, SIGNAL(triggered()), this, SLOT(saveHdrPreview()));
 
 	//QSignalMapper?
 	connect(actionText_Under_Icons,SIGNAL(triggered()),this,SLOT(Text_Under_Icons()));
@@ -102,13 +105,12 @@ MainGui::MainGui(QWidget *p) : QMainWindow(p), currenthdr(NULL), settings("Qtpfs
 	connect(windowMapper,SIGNAL(mapped(QWidget*)),workspace,SLOT(setActiveWindow(QWidget*)));
 
 	//recent files
-        for (int i = 0; i < MaxRecentFiles; ++i) {
-            recentFileActs[i] = new QAction(this);
-            recentFileActs[i]->setVisible(false);
-            connect(recentFileActs[i], SIGNAL(triggered()),
-                    this, SLOT(openRecentFile()));
-        }
-        separatorRecentFiles = menuFile->addSeparator();
+	for (int i = 0; i < MaxRecentFiles; ++i) {
+		recentFileActs[i] = new QAction(this);
+		recentFileActs[i]->setVisible(false);
+		connect(recentFileActs[i], SIGNAL(triggered()), this, SLOT(openRecentFile()));
+	}
+	separatorRecentFiles = menuFile->addSeparator();
 	for (int i = 0; i < MaxRecentFiles; ++i)
 		menuFile->addAction(recentFileActs[i]);
 	updateRecentFileActions();
@@ -120,7 +122,7 @@ MainGui::MainGui(QWidget *p) : QMainWindow(p), currenthdr(NULL), settings("Qtpfs
 void MainGui::fileNewViaWizard() {
 	HdrWizardForm *wizard;
 	if (testTempDir(qtpfsgui_options->tempfilespath)) {
-		wizard=new HdrWizardForm (this,qtpfsgui_options);
+		wizard=new HdrWizardForm (this);
 		if (wizard->exec() == QDialog::Accepted) {
 			HdrViewer *newmdi=new HdrViewer( this, qtpfsgui_options->negcolor, qtpfsgui_options->naninfcolor, true); //true means needs saving
 			newmdi->updateHDR(wizard->getPfsFrameHDR());
@@ -132,13 +134,14 @@ void MainGui::fileNewViaWizard() {
 	}
 }
 
+
 void MainGui::fileOpen() {
 	QString filetypes = tr("All Hdr formats ");
-	filetypes += "(*.exr *.hdr *.pic *.tiff *.tif *.pfs *.crw *.cr2 *.nef *.dng *.mrw *.orf *.kdc *.dcr *.arw *.raf *.ptx *.pef *.x3f *.raw);;" ;
+	filetypes += "(*.exr *.hdr *.pic *.tiff *.tif *.pfs *.crw *.cr2 *.nef *.dng *.mrw *.orf *.kdc *.dcr *.arw *.raf *.ptx *.pef *.x3f *.raw *.sr2);;" ;
 	filetypes += "OpenEXR (*.exr);;" ;
 	filetypes += "Radiance RGBE (*.hdr *.pic);;";
 	filetypes += "TIFF Images (*.tiff *.tif);;";
-	filetypes += "RAW Images (*.crw *.cr2 *.nef *.dng *.mrw *.orf *.kdc *.dcr *.arw *.raf *.ptx *.pef *.x3f *.raw);;";
+	filetypes += "RAW Images (*.crw *.cr2 *.nef *.dng *.mrw *.orf *.kdc *.dcr *.arw *.raf *.ptx *.pef *.x3f *.raw *.sr2);;";
 	filetypes += "PFS Stream (*.pfs)";
 	QString filename = QFileDialog::getOpenFileName(
 			this,
@@ -222,7 +225,15 @@ void MainGui::fileSaveAs()
 	delete fd;
 }
 
+void MainGui::saveHdrPreview() {
+	if(currenthdr==NULL)
+		return;
+	currenthdr->saveHdrPreview();
+}
+
 void MainGui::updateActions( QWidget * w ) {
+	action_Projective_Transformation->setEnabled(w!=NULL);
+	actionSave_Hdr_Preview->setEnabled(w!=NULL);
 	TonemapAction->setEnabled(w!=NULL);
 	fileSaveAsAction->setEnabled(w!=NULL);
 	rotateccw->setEnabled(w!=NULL);
@@ -327,6 +338,23 @@ void MainGui::resize_requested() {
 	delete resizedialog;
 }
 
+void MainGui::projectiveTransf_requested() {
+	if (currenthdr==NULL)
+		return;
+	projectiveTransformDialog *projTranfsDialog=new projectiveTransformDialog(this,currenthdr->getHDRPfsFrame());
+	if (projTranfsDialog->exec() == QDialog::Accepted) {
+		QApplication::setOverrideCursor( QCursor(Qt::WaitCursor) );
+		//updateHDR() method takes care of deleting its previous pfs::Frame* buffer.
+		currenthdr->updateHDR(projTranfsDialog->getTranformedFrame());
+		if (! currenthdr->NeedsSaving) {
+			currenthdr->NeedsSaving=true;
+			currenthdr->setWindowTitle(currenthdr->windowTitle().prepend("(*) "));
+		}
+		QApplication::restoreOverrideCursor();
+	}
+	delete projTranfsDialog;
+}
+
 void MainGui::current_mdi_decrease_exp() {
 	currenthdr->lumRange->decreaseExposure();
 }
@@ -417,7 +445,7 @@ void MainGui::openRecentFile() {
 }
 
 void MainGui::setupLoadThread(QString fname) {
-	LoadHdrThread *loadthread = new LoadHdrThread(fname, RecentDirHDRSetting, qtpfsgui_options);
+	LoadHdrThread *loadthread = new LoadHdrThread(fname, RecentDirHDRSetting);
 	connect(loadthread, SIGNAL(updateRecentDirHDRSetting(QString)), this, SLOT(updateRecentDirHDRSetting(QString)));
 	connect(loadthread, SIGNAL(hdr_ready(pfs::Frame*,QString)), this, SLOT(addHdrViewer(pfs::Frame*,QString)));
 	connect(loadthread, SIGNAL(load_failed(QString)), this, SLOT(load_failed(QString)));
@@ -435,10 +463,10 @@ void MainGui::load_failed(QString error_message) {
 	updateRecentFileActions();
 }
 
-void MainGui::options_called() {
+void MainGui::preferences_called() {
 	unsigned int negcol=qtpfsgui_options->negcolor;
 	unsigned int naninfcol=qtpfsgui_options->naninfcolor;
-	QtpfsguiOptions *opts=new QtpfsguiOptions(this,qtpfsgui_options,&settings);
+	PreferenceDialog *opts=new PreferenceDialog(this);
 	opts->setAttribute(Qt::WA_DeleteOnClose);
 	if (opts->exec() == QDialog::Accepted && (negcol!=qtpfsgui_options->negcolor || naninfcol!=qtpfsgui_options->naninfcolor) ) {
 		QWidgetList allhdrs=workspace->windowList();
@@ -454,7 +482,7 @@ void MainGui::transplant_called() {
 	transplant->exec();
 }
 
-void MainGui::load_options(qtpfsgui_opts *dest) {
+void MainGui::load_options() {
 	//load from settings the path where hdrs have been previously opened/loaded
 	RecentDirHDRSetting=settings.value(KEY_RECENT_PATH_LOAD_SAVE_HDR,QDir::currentPath()).toString();
 
@@ -479,12 +507,9 @@ void MainGui::load_options(qtpfsgui_opts *dest) {
 		actionText_Under_Icons->setChecked(true);
 	break;
 	}
-
-	QtPfsGuiOptions::loadOptions(dest);
 }
 
 MainGui::~MainGui() {
-	delete qtpfsgui_options;
 	for (int i = 0; i < MaxRecentFiles; ++i) {
 		delete recentFileActs[i];
 	}
@@ -543,7 +568,7 @@ void MainGui::aboutQtpfsgui() {
 	bool license_file_not_found=true;
 	QString docDir = QCoreApplication::applicationDirPath();
 	docDir.append("/../Resources");
-	QStringList paths = QStringList("/usr/share/qtpfsgui") << "/usr/local/share/qtpfsgui" << "./" << docDir << "/Applications/qtpfsgui.app/Contents/Resources";
+	QStringList paths = QStringList("/usr/share/qtpfsgui") << "/usr/local/share/qtpfsgui" << docDir << "/Applications/qtpfsgui.app/Contents/Resources" << "./";
 	foreach (QString path,paths) {
 		QString fname(path+QString("/LICENSE"));
 #ifdef WIN32
@@ -589,7 +614,7 @@ void MainGui::updateWindowMenu() {
 }
 
 void MainGui::batch_requested() {
-	BatchTMDialog *batchdialog=new BatchTMDialog(this, qtpfsgui_options);
+	BatchTMDialog *batchdialog=new BatchTMDialog(this);
 	batchdialog->exec();
 	delete batchdialog;
 }
