@@ -35,9 +35,11 @@
 extern int xsize;
 extern float pregamma;
 
-TMWidget::TMWidget(QWidget *parent, pfs::Frame* &_OriginalPfsFrame, QString cachepath, QStatusBar *_sb) : QWidget(parent), OriginalPfsFrame(_OriginalPfsFrame), settings("Qtpfsgui", "Qtpfsgui"), cachepath(cachepath), sb(_sb), adding_custom_size(false) {
+TMWidget::TMWidget(QWidget *parent, pfs::Frame* &_OriginalPfsFrame, QStatusBar *_sb) : QWidget(parent), OriginalPfsFrame(_OriginalPfsFrame), sb(_sb), adding_custom_size(false) {
 	setupUi(this);
 
+	cachepath=QtpfsguiOptions::getInstance()->tempfilespath;
+
 	// mantiuk06
 	contrastfactorGang = new Gang(contrastFactorSlider, contrastFactordsb,0.001,2,0.3);
 	saturationfactorGang = new Gang(saturationFactorSlider, saturationFactordsb,0,2,0.8);
